==> aravis-0.1.2.tar.bz2: aravis-0.1.2/src/arvenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef ARV_ENUM_TYPES_H
#define ARV_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "arvenums.h" */

#define ARV_TYPE_GC_NAME_SPACE	(arv_gc_name_space_get_type())
GType arv_gc_name_space_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_ACCESS_MODE	(arv_gc_access_mode_get_type())
GType arv_gc_access_mode_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_CACHABLE	(arv_gc_cachable_get_type())
GType arv_gc_cachable_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_ACQUISITION_MODE	(arv_acquisition_mode_get_type())
GType arv_acquisition_mode_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_PIXEL_FORMAT	(arv_pixel_format_get_type())
GType arv_pixel_format_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvcamera.h" */

#define ARV_TYPE_CAMERA_VENDOR	(arv_camera_vendor_get_type())
GType arv_camera_vendor_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgcregister.h" */

#define ARV_TYPE_GC_SIGN	(arv_gc_sign_get_type())
GType arv_gc_sign_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_REGISTER_TYPE	(arv_gc_register_type_get_type())
GType arv_gc_register_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvstream.h" */

#define ARV_TYPE_STREAM_CALLBACK_TYPE	(arv_stream_callback_type_get_type())
GType arv_stream_callback_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvbuffer.h" */

#define ARV_TYPE_BUFFER_STATUS	(arv_buffer_status_get_type())
GType arv_buffer_status_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvcp.h" */

#define ARV_TYPE_GVCP_PACKET_TYPE	(arv_gvcp_packet_type_get_type())
GType arv_gvcp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVCP_COMMAND	(arv_gvcp_command_get_type())
GType arv_gvcp_command_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvsp.h" */

#define ARV_TYPE_GVSP_PACKET_TYPE	(arv_gvsp_packet_type_get_type())
GType arv_gvsp_packet_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvstream.h" */

#define ARV_TYPE_GV_STREAM_OPTION	(arv_gv_stream_option_get_type())
GType arv_gv_stream_option_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GV_STREAM_PACKET_RESEND	(arv_gv_stream_packet_resend_get_type())
GType arv_gv_stream_packet_resend_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* ARV_ENUM_TYPES_H */

/* Generated data ends here */

==> aravis-0.1.4.tar.bz2: aravis-0.1.4/src/arvenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef ARV_ENUM_TYPES_H
#define ARV_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "arvenums.h" */

#define ARV_TYPE_GC_NAME_SPACE	(arv_gc_name_space_get_type())
GType arv_gc_name_space_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_ACCESS_MODE	(arv_gc_access_mode_get_type())
GType arv_gc_access_mode_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_CACHABLE	(arv_gc_cachable_get_type())
GType arv_gc_cachable_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_AUTO	(arv_auto_get_type())
GType arv_auto_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_ACQUISITION_MODE	(arv_acquisition_mode_get_type())
GType arv_acquisition_mode_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_PIXEL_FORMAT	(arv_pixel_format_get_type())
GType arv_pixel_format_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgcregister.h" */

#define ARV_TYPE_GC_SIGN	(arv_gc_sign_get_type())
GType arv_gc_sign_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GC_REGISTER_TYPE	(arv_gc_register_type_get_type())
GType arv_gc_register_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvstream.h" */

#define ARV_TYPE_STREAM_CALLBACK_TYPE	(arv_stream_callback_type_get_type())
GType arv_stream_callback_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvbuffer.h" */

#define ARV_TYPE_BUFFER_STATUS	(arv_buffer_status_get_type())
GType arv_buffer_status_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvcp.h" */

#define ARV_TYPE_GVCP_PACKET_TYPE	(arv_gvcp_packet_type_get_type())
GType arv_gvcp_packet_type_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GVCP_COMMAND	(arv_gvcp_command_get_type())
GType arv_gvcp_command_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvsp.h" */

#define ARV_TYPE_GVSP_PACKET_TYPE	(arv_gvsp_packet_type_get_type())
GType arv_gvsp_packet_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "arvgvstream.h" */

#define ARV_TYPE_GV_STREAM_OPTION	(arv_gv_stream_option_get_type())
GType arv_gv_stream_option_get_type	(void) G_GNUC_CONST;

#define ARV_TYPE_GV_STREAM_PACKET_RESEND	(arv_gv_stream_packet_resend_get_type())
GType arv_gv_stream_packet_resend_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* ARV_ENUM_TYPES_H */

/* Generated data ends here */
